==> istio-model-1.0.0-sources.jar: me/snowdrop/istio/mixer/template/reportnothing/ReportNothingListFluent.java <==
package me.snowdrop.istio.mixer.template.reportnothing;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import javax.validation.constraints.NotNull;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface ReportNothingListFluent<A extends ReportNothingListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A addToItems(int index,ReportNothing item);
    public A setToItems(int index,ReportNothing item);
    public A addToItems(ReportNothing... items);
    public A addAllToItems(Collection<ReportNothing> items);
    public A removeFromItems(ReportNothing... items);
    public A removeAllFromItems(Collection<ReportNothing> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<ReportNothing> getItems();
    public List<ReportNothing> buildItems();
    public ReportNothing buildItem(int index);
    public ReportNothing buildFirstItem();
    public ReportNothing buildLastItem();
    public ReportNothing buildMatchingItem(Predicate<ReportNothingBuilder> predicate);
    public A withItems(List<ReportNothing> items);
    public A withItems(ReportNothing... items);
    public Boolean hasItems();
    public ReportNothingListFluent.ItemsNested<A> addNewItem();
    public ReportNothingListFluent.ItemsNested<A> addNewItemLike(ReportNothing item);
    public ReportNothingListFluent.ItemsNested<A> setNewItemLike(int index,ReportNothing item);
    public ReportNothingListFluent.ItemsNested<A> editItem(int index);
    public ReportNothingListFluent.ItemsNested<A> editFirstItem();
    public ReportNothingListFluent.ItemsNested<A> editLastItem();
    public ReportNothingListFluent.ItemsNested<A> editMatchingItem(Predicate<ReportNothingBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,ReportNothingFluent<ReportNothingListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/template/reportnothing/ReportNothingListFluent.java <==
package me.snowdrop.istio.mixer.template.reportnothing;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface ReportNothingListFluent<A extends ReportNothingListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,ReportNothing item);
    public A setToItems(int index,ReportNothing item);
    public A addToItems(ReportNothing... items);
    public A addAllToItems(Collection<ReportNothing> items);
    public A removeFromItems(ReportNothing... items);
    public A removeAllFromItems(Collection<ReportNothing> items);
    public A removeMatchingFromItems(Predicate<ReportNothingBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<ReportNothing> getItems();
    public List<ReportNothing> buildItems();
    public ReportNothing buildItem(int index);
    public ReportNothing buildFirstItem();
    public ReportNothing buildLastItem();
    public ReportNothing buildMatchingItem(Predicate<ReportNothingBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<ReportNothingBuilder> predicate);
    public A withItems(List<ReportNothing> items);
    public A withItems(ReportNothing... items);
    public Boolean hasItems();
    public ReportNothingListFluent.ItemsNested<A> addNewItem();
    public ReportNothingListFluent.ItemsNested<A> addNewItemLike(ReportNothing item);
    public ReportNothingListFluent.ItemsNested<A> setNewItemLike(int index,ReportNothing item);
    public ReportNothingListFluent.ItemsNested<A> editItem(int index);
    public ReportNothingListFluent.ItemsNested<A> editFirstItem();
    public ReportNothingListFluent.ItemsNested<A> editLastItem();
    public ReportNothingListFluent.ItemsNested<A> editMatchingItem(Predicate<ReportNothingBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,ReportNothingFluent<ReportNothingListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}
